@@ -27,6 +27,7 @@
 
 from email import message_from_string, policy
 from email.message import EmailMessage
+from io import BytesIO
 import os
 import subprocess
 from tempfile import mkdtemp, NamedTemporaryFile
@@ -44,18 +45,26 @@ from faker_file.providers.txt_file import TxtFileProvider
 from faker_file.providers.xml_file import XmlFileProvider
 
 from cardinal_pythonlib.extract_text import (
+    convert_msg_to_text,
     document_to_text,
     TextProcessingConfig,
     update_external_tools,
 )
 
 
-class DocumentToTextTests(TestCase):
+class ExtractTextTestCase(TestCase):
     def setUp(self) -> None:
+        self.config = TextProcessingConfig()
+        self.fake = Faker("en-US")  # en-US to avoid Lorem Ipsum from en-GB
+        self.fake.seed_instance(12345)
+
+
+class DocumentToTextTests(ExtractTextTestCase):
+    def setUp(self) -> None:
+        super().setUp()
         self.empty_dir = mkdtemp()
 
         self._replace_external_tools_with_fakes()
-        self.config = TextProcessingConfig()
         self._create_mock_objects()
         self._register_faker_providers()
 
@@ -69,8 +78,6 @@ class DocumentToTextTests(TestCase):
         )
 
     def _register_faker_providers(self) -> None:
-        self.fake = Faker("en-US")  # To avoid Lorem Ipsum
-        self.fake.seed_instance(12345)
         self.fake.add_provider(DocxFileProvider)
         self.fake.add_provider(EmlFileProvider)
         self.fake.add_provider(OdtFileProvider)
@@ -109,13 +116,13 @@ class DocumentToTextTests(TestCase):
 
     def test_raises_when_filename_and_blob(self) -> None:
         with self.assertRaises(ValueError) as cm:
-            document_to_text(filename="foo", blob="bar")
+            document_to_text(filename="foo", blob=b"bar")
 
         self.assertIn("specify either filename or blob", str(cm.exception))
 
     def test_raises_when_blob_but_no_extension(self) -> None:
         with self.assertRaises(ValueError) as cm:
-            document_to_text(blob="bar")
+            document_to_text(blob=b"bar")
 
         self.assertIn("need extension hint for blob", str(cm.exception))
 
@@ -586,3 +593,125 @@ Content-Transfer-Encoding: quoted-printable
             ),
         ]
         self.mock_popen.assert_has_calls(expected_calls)
+
+
+class ConvertMsgToTextTests(ExtractTextTestCase):
+    # There is no easy way to create test Outlook msg files and we don't want
+    # to store real ones so we mock the interface to extract-msg and assume the
+    # library itself is working correctly.
+    def setUp(self) -> None:
+        super().setUp()
+        self.dummy_filename = "dummy_filename.msg"
+        self.dummy_blob = b"dummy blob"
+
+    def test_raises_when_no_filename_or_blob(self) -> None:
+        with self.assertRaises(ValueError) as cm:
+            convert_msg_to_text()
+
+        self.assertIn("no filename and no blob", str(cm.exception))
+
+    def test_raises_when_filename_and_blob(self) -> None:
+        with self.assertRaises(ValueError) as cm:
+            convert_msg_to_text(filename="foo", blob=b"bar")
+
+        self.assertIn("specify either filename or blob", str(cm.exception))
+
+    def test_blob_passed_to_openmsg(self) -> None:
+        content = self.fake.paragraph(nb_sentences=10)
+
+        mock_msgfile = mock.Mock(body=content, htmlBody=None, attachments=[])
+        mock_openmsg = mock.Mock(return_value=mock_msgfile)
+        with mock.patch.multiple(
+            "cardinal_pythonlib.extract_text",
+            openMsg=mock_openmsg,
+        ):
+            convert_msg_to_text(blob=self.dummy_blob, config=self.config)
+
+        expected_calls = [mock.call(self.dummy_blob, delayAttachments=False)]
+        mock_openmsg.assert_has_calls(expected_calls)
+
+    def test_file_passed_to_openmsg(self) -> None:
+        content = self.fake.paragraph(nb_sentences=10)
+
+        mock_msgfile = mock.Mock(body=content, htmlBody=None, attachments=[])
+        mock_openmsg = mock.Mock(return_value=mock_msgfile)
+        with mock.patch.multiple(
+            "cardinal_pythonlib.extract_text",
+            openMsg=mock_openmsg,
+        ):
+            convert_msg_to_text(
+                filename=self.dummy_filename, config=self.config
+            )
+
+        expected_calls = [
+            mock.call(self.dummy_filename, delayAttachments=False)
+        ]
+        mock_openmsg.assert_has_calls(expected_calls)
+
+    def test_text_body_converted(self) -> None:
+        content = self.fake.paragraph(nb_sentences=10)
+
+        mock_msgfile = mock.Mock(body=content, htmlBody=None, attachments=[])
+        mock_openmsg = mock.Mock(return_value=mock_msgfile)
+        with mock.patch.multiple(
+            "cardinal_pythonlib.extract_text",
+            openMsg=mock_openmsg,
+        ):
+            converted = convert_msg_to_text(
+                filename=self.dummy_filename, config=self.config
+            )
+
+        self.assertEqual(converted, content)
+
+    def test_html_body_converted(self) -> None:
+        content = self.fake.paragraph(nb_sentences=10)
+        html = f"""
+<!DOCTYPE html>
+<html>
+<head>
+</head>
+<body>
+{content}
+</body>
+</html>
+"""
+
+        mock_msgfile = mock.Mock(
+            body=None, htmlBody=html.encode("utf-8"), attachments=[]
+        )
+        mock_openmsg = mock.Mock(return_value=mock_msgfile)
+        with mock.patch.multiple(
+            "cardinal_pythonlib.extract_text",
+            openMsg=mock_openmsg,
+        ):
+            converted = convert_msg_to_text(
+                filename=self.dummy_filename, config=self.config
+            )
+
+        self.assertEqual(converted.strip(), content)
+
+    def test_attachment_converted(self) -> None:
+        self.fake.add_provider(DocxFileProvider)
+
+        dummy_filename = "dummy_filename.msg"
+
+        content = self.fake.paragraph(nb_sentences=10)
+        docx = self.fake.docx_file(content=content, raw=True)
+        mock_attachment = mock.Mock(
+            # null termination seen in the real world
+            # https://github.com/TeamMsgExtractor/msg-extractor/issues/464
+            extension=".docx\x00",
+            data=BytesIO(docx).read(),
+        )
+        mock_msgfile = mock.Mock(
+            body=None, htmlBody=None, attachments=[mock_attachment]
+        )
+        mock_openmsg = mock.Mock(return_value=mock_msgfile)
+        with mock.patch.multiple(
+            "cardinal_pythonlib.extract_text",
+            openMsg=mock_openmsg,
+        ):
+            self.config.width = 0
+            converted = convert_msg_to_text(dummy_filename, config=self.config)
+
+        self.assertEqual(converted.strip(), content)
